<?php

/**
 * @file
 * Contains Drupal\yamlform\Form\YamlFormResultsClearForm.
 */

namespace Drupal\yamlform\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\yamlform\YamlFormInterface;
use Drupal\yamlform\YamlFormSubmissionStorage;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form for YAML form results clear form.
 */
class YamlFormResultsClearForm extends ConfirmFormBase {

  /**
   * The YAML form entity.
   *
   * @var \Drupal\yamlform\Entity\YamlForm
   */
  protected $yamlform;

  /**
   * The YAML form submission storage.
   *
   * @var \Drupal\yamlform\YamlFormSubmissionStorage
   */
  protected $submissionStorage;

  /**
   * Constructs a new YamlFormResultsClearForm object.
   *
   * @param \Drupal\yamlform\YamlFormSubmissionStorage $yamlform_submission_storage
   *   The YAML form submission storage.
   */
  public function __construct(YamlFormSubmissionStorage $yamlform_submission_storage) {
    $this->submissionStorage = $yamlform_submission_storage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity.manager')->getStorage('yamlform_submission')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'yamlform_results_clear';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete all submissions to %title form?', ['%title' => $this->yamlform->label()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Clear');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('entity.yamlform.results_submissions', ['yamlform' => $this->yamlform->id()]);
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, YamlFormInterface $yamlform = NULL) {
    $this->yamlform = $yamlform;
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->submissionStorage->deleteAll($this->yamlform);

    drupal_set_message($this->t('Form %title submissions cleared.', ['%title' => $this->yamlform->label()]));
    $form_state->setRedirect('entity.yamlform.canonical', ['yamlform' => $this->yamlform->id()]);
  }

}
