<?php
/**
 * @file
 * Contains \Drupal\yamlform\Plugin\Block\YamlFormBlock.
 */

namespace Drupal\yamlform\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\yamlform\Entity\YamlForm;

/**
 * Provides a 'YAML form' block.
 *
 * @Block(
 *   id = "yamlform_block",
 *   admin_label = @Translation("YAML form"),
 *   category = @Translation("YAML form")
 * )
 */
class YamlFormBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'yamlform_id' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form['yamlform_id'] = [
      '#title' => $this->t('YAML form'),
      '#type' => 'entity_autocomplete',
      '#target_type' => 'yamlform',
      '#required' => TRUE,
      '#default_value' => $this->getYamlForm(),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['yamlform_id'] = $form_state->getValue('yamlform_id');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return $this->getYamlForm()->getSubmissionForm();
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    $yamlform = $this->getYamlForm();
    if (!$yamlform || !$yamlform->access('view')) {
      return AccessResult::forbidden();
    }
    else {
      return parent::blockAccess($account);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    // TODO: (PERFORMANCE) Look into a better caching strategy.
    // For example, only YAML forms that display confirmation messages
    // should never be cached.
    return 0;
  }

  /**
   * Get this block instance YAML form.
   *
   * @return \Drupal\yamlform\Entity\YamlForm
   *   A YAML form or NULL.
   */
  protected function getYamlForm() {
    return YamlForm::load($this->configuration['yamlform_id']);
  }

}
