<?php

/**
 * @file
 * Contains \Drupal\yamlform\Plugin\YamlFormElement\DateBase.
 */

namespace Drupal\yamlform\Plugin\YamlFormElement;

use Drupal\Core\Datetime\Entity\DateFormat;
use Drupal\Core\Form\FormStateInterface;
use Drupal\yamlform\YamlFormElementBase;

/**
 * Provides a base 'date' class.
 */
abstract class DateBase extends YamlFormElementBase {

  /**
   * {@inheritdoc}
   */
  public function formatText(array &$element, $value) {
    if (isset($element['#date_format'])) {
      $format = ($date_format = DateFormat::load($element['#date_format'])) ? $date_format->getPattern() : $element['#date_format'];
    }
    else {
      switch ($element['#type']) {
        case 'datelist':
          $format = (isset($element['#date_part_order']) && !in_array($element['#date_part_order'], 'hour')) ? 'html_date' : 'html_datetime';
          break;

        default:
          $format = 'html_' . $element['#type'];
          break;
      }
    }
    return ($timestamp = strtotime($value)) ? format_date($timestamp, $format) : $value;
  }

  /**
   * Form API callback. Convert DrupalDateTime array and object to ISO datetime.
   */
  public static function validate(array &$element, FormStateInterface $form_state) {
    $name = $element['#name'];
    $value = $form_state->getValue($name);
    /** @var \Drupal\Core\Datetime\DrupalDateTime $datetime */
    if ($datetime = $value['object']) {
      $form_state->setValue($name, $datetime->format('c') ?: '');
    }
    else {
      $form_state->setValue($name, '');
    }
  }

}
