<?php

/**
 * @file
 * Contains \Drupal\yamlform\Plugin\YamlFormElement\EntityAutocomplete.
 */

namespace Drupal\yamlform\Plugin\YamlFormElement;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\yamlform\Utility\YamlFormEntityReferenceHelper;
use Drupal\yamlform\YamlFormElementBase;

/**
 * Provides a 'entity_autocomplete' element.
 *
 * @YamlFormElement(
 *   id = "entity_autocomplete",
 *   label = @Translation("Entity autocomplete"),
 *   description = @Translation("Handles normalizing and displaying of an entity autocomplete element.")
 * )
 */
class EntityAutocomplete extends YamlFormElementBase {

  /**
   * {@inheritdoc}
   */
  public function setDefaultValue(array &$element, $default_value) {
    if (isset($element['#default_value']) && (!empty($element['#default_value']) || $element['#default_value'] === 0)) {
      if (!empty($element['#tags'])) {
        $entity_ids = YamlFormEntityReferenceHelper::getTargetEntityIds($element['#default_value']);
        $element['#default_value'] = ($entity_ids) ? entity_load_multiple($element['#target_type'], $entity_ids) : [];
      }
      else {
        $element['#default_value'] = entity_load($element['#target_type'], $element['#default_value']) ?: NULL;
      }
    }
    else {
      $element['#default_value'] = NULL;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function formatHtml(array &$element, $value) {
    return YamlFormEntityReferenceHelper::formatTargetEntities($element['#target_type'], $value);
  }

  /**
   * {@inheritdoc}
   */
  public function formatText(array &$element, $value) {
    $entity = entity_load($element['#target_type'], $value);
    return ($entity) ? new FormattableMarkup('@label (@id)', ['@label' => $entity->label(), '@id' => $entity->id()]) : $value;
  }

}
