<?php

/**
 * @file
 * Definition of Drupal\yamlform\test\YamlFormCodeMirrorTest.
 */

namespace Drupal\yamlform\Tests;

use Drupal\simpletest\WebTestBase;
use Drupal\yamlform\Entity\YamlForm;

/**
 * Tests for YAML form CodeMirror element.
 *
 * @group YamlForm
 */
class YamlFormCodeMirrorTest extends WebTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['system', 'block', 'node', 'user', 'yamlform', 'yamlform_test'];

  /**
   * Test CodeMirror element.
   */
  public function testCodeMirrorElement() {
    $user = $this->drupalCreateUser(['access yamlform']);;
    $this->drupalLogin($user);

    // See: yamlform.yamlform.test_element_codemirror.yml.
    /** @var \Drupal\yamlform\YamlFormInterface $yamlform */
    $yamlform = YamlForm::load('test_element_codemirror');

    $this->drupalGet('yamlform/' . $yamlform->id());

    // Check for textarea with yamlform-codemirror class name.
    $this->assertRaw('<textarea data-drupal-selector="edit-yaml" class="yamlform-codemirror form-textarea resize-vertical" id="edit-yaml" name="yaml" rows="5" cols="60"></textarea>');

    // Check submitting invalid YAML.
    $this->drupalPostForm('yamlform/' . $yamlform->id(), ['yaml' => "not\nvalid\nyaml"], t('Submit'));
    $this->assertFieldByName('yaml', "not\nvalid\nyaml");
    $this->assertRaw('<em class="placeholder">YAML</em> is not valid. Unable to parse at line 1 (near &quot;not&quot;).');

    // Check submitting valid YAML.
    $this->drupalPostForm('yamlform/' . $yamlform->id(), ['yaml' => "valid: yaml"], t('Submit'));
    $this->assertRaw('<a href="' . $yamlform->toUrl()->toString() . '">' . t('Back to form') . '</a>');
    $this->assertNoRaw('<em class="placeholder">YAML</em> is not valid..');
  }

}
