<?php

/**
 * @file
 * Definition of Drupal\yamlform\test\YamlFormTest.
 */

namespace Drupal\yamlform\Tests;

/**
 * Tests for YAML form entity.
 *
 * @group YamlForm
 */
class YamlFormTest extends YamlFormTestBase {

  /**
   * Tests YAML form entity.
   */
  public function testYamlForm() {
    /** @var \Drupal\yamlform\YamlFormInterface $yamlform */
    /** @var \Drupal\yamlform\Entity\YamlFormSubmission[] $submissions */
    list($yamlform, $submissions) = $this->createYamlFormWithSubmissions();

    // Check get inputs.
    $inputs = $yamlform->getInputs();
    $this->assert(is_array($inputs));

    // Check getInputColumns.
    $columns = $yamlform->getInputColumns();
    $this->assertEqual(array_keys($columns), ['first_name', 'last_name', 'sex', 'dob', 'node', 'colors']);

    // Check getElementOptions for manually defined options.
    $this->assertEqual($yamlform->getElementOptions($inputs['colors']), [
      'red' => 'Red',
      'white' => 'White',
      'blue' => 'Blue',
    ]);

    // Check getElementOptions for token options pulled from YamlFormOptions.
    $this->assertEqual($yamlform->getElementOptions($inputs['sex']), [
      'Male' => 'Male',
      'Female' => 'Female',
    ]);

    // Set invalid inputs.
    $yamlform->set('inputs', "not\nvalid\nyaml")->save();

    // Check invalid inputs.
    $this->assertFalse($yamlform->getInputs());

    // Check invalid input columns.
    $this->assertEqual($yamlform->getInputColumns(), []);

    // Check for 3 submissions..
    $this->assertEqual($this->submissionStorage->getTotal($yamlform), 3);

    // Check get options.
    $yes_no_options = ['Yes' => 'Yes', 'No' => 'No'];
    $this->assertEqual($yamlform->getElementOptions(['#options' => $yes_no_options]), $yes_no_options);
    $this->assertEqual($yamlform->getElementOptions(['#options' => 'yes_no']), $yes_no_options);
    $this->assertEqual($yamlform->getElementOptions(['#options' => 'not-found']), []);

    // Check delete.
    $yamlform->delete();

    // Check all 3 submissions deleted.
    $this->assertEqual($this->submissionStorage->getTotal($yamlform), 0);
  }

}
