<?php

/**
 * @file
 * Definition of Drupal\yamlform\Utility\YamlFormEntityReferenceHelper.
 */

namespace Drupal\yamlform\Utility;

use Drupal\Component\Render\FormattableMarkup;

/**
 * Helper class YAML form entity reference based methods.
 */
class YamlFormEntityReferenceHelper {

  /**
   * Get entity target ids from entity reference/autocomplete item value(s).
   *
   * @param array|int $value
   *   An array of items containing 'target_id' or an entity id.
   *
   * @return array
   *   An associative array with entity ids as the key/value pairs.
   */
  public static function getTargetEntityIds($value) {
    $entity_ids = [];
    if (is_array($value)) {
      foreach ($value as $item) {
        $entity_ids[$item['target_id']] = $item['target_id'];
      }
    }
    else {
      $entity_ids = [$value => $value];
    }
    return $entity_ids;
  }

  /**
   * Format entity targets from entity reference/autocomplete item value(s).
   *
   * @param string $target_type
   *   The targeted entity type.
   * @param array|int $value
   *   An array of items containing 'target_id' or an entity id.
   * @param bool $link
   *   If TRUE, returned entities will be linked to their canonical URL.
   *
   * @return \Drupal\Component\Render\FormattableMarkup
   *   Markup contain comma delimited entities.
   */
  public static function formatTargetEntities($target_type, $value, $link = TRUE) {
    $entity_ids = self::getTargetEntityIds($value);
    $entities = entity_load_multiple($target_type, $entity_ids);
    foreach ($entities as $entity_id => $entity) {
      $entity_ids[$entity_id] = ($link && method_exists($entity, 'toLink'))
        ? $entity->link()
        : new FormattableMarkup('@label (@id)', ['@label' => $entity->label(), '@id' => $entity->id()]);
    }
    return new FormattableMarkup(implode(', ', $entity_ids), []);
  }

}
