<?php

/**
 * @file
 * Definition of Drupal\yamlform\Utility\YamlFormOptionsHelper.
 */

namespace Drupal\yamlform\Utility;

/**
 * Helper class YAML form options based methods.
 */
class YamlFormOptionsHelper {

  /**
   * Get flattened options.
   *
   * @param array $options
   *   An associative array of options with optgroups.
   *
   * @return array
   *   An associative array of option value and names.
   */
  public static function flattenOptions(array $options) {
    $flattened = [];
    foreach ($options as $value => $text) {
      if (is_array($text)) {
        $flattened += self::flattenOptions($text);
      }
      else {
        $flattened[$value] = $text;
      }
    }
    return $flattened;
  }

  /**
   * Get the text string for an option value.
   *
   * @param array $values
   *   The option value.
   * @param array $options
   *   An associative array of options.
   *
   * @return string
   *   The option text if found or the option value.
   */
  public static function getOptionsText(array $values, array $options) {
    foreach ($values as &$value) {
      $value = self::getOptionText($value, $options);
    }
    return $values;
  }

  /**
   * Get the text string for an option value.
   *
   * @param string $value
   *   The option value.
   * @param array $options
   *   An associative array of options.
   *
   * @return string
   *   The option text if found or the option value.
   */
  public static function getOptionText($value, array $options) {
    foreach ($options as $option_value => $option_text) {
      if ($value == $option_value) {
        return $option_text;
      }
      elseif (is_array($option_text)) {
        if ($text = self::getOptionText($value, $option_text)) {
          return $text;
        }
      }
    }
    return $value;
  }

}
