<?php

/**
 * @file
 * Provides Drupal\yamlform\YamlFormElementInterface.
 */

namespace Drupal\yamlform;

use Drupal\Component\Plugin\PluginInspectionInterface;

/**
 * Defines the interface for YAML form elements.
 *
 * @see \Drupal\yamlform\Annotation\YamlFormElement
 * @see \Drupal\yamlform\YamlFormElementBase
 * @see \Drupal\yamlform\YamlFormElementManager
 * @see plugin_api
 */
interface YamlFormElementInterface extends PluginInspectionInterface {

  /**
   * Returns the YAML form element label.
   *
   * @return string
   *   The YAML form handler label.
   */
  public function label();

  /**
   * Returns the YAML form element description.
   *
   * @return string
   *   The YAML form handler description.
   */
  public function description();

  /**
   * Prepare an element to be rendered within a form.
   *
   * @param array $element
   *   An element.
   * @param \Drupal\yamlform\YamlFormSubmissionInterface $yamlform_submission
   *   A YAML form submission.
   */
  public function prepare(array &$element, YamlFormSubmissionInterface $yamlform_submission);

  /**
   * Set an element's default value using saved data.
   *
   * @param array $element
   *   An element.
   * @param array|mixed $default_value
   *   Saved value which is usually just that data that is sent to the server
   *   when a form element is submitted via a form.
   */
  public function setDefaultValue(array &$element, $default_value);

  /**
   * Save any additional value associated with an element.
   *
   * Currently only applicable to file uploads.
   *
   * @param array $element
   *   An element.
   * @param \Drupal\yamlform\YamlFormSubmissionInterface $yamlform_submission
   *   A YAML form submission.
   */
  public function save(array &$element, YamlFormSubmissionInterface $yamlform_submission);

  /**
   * Delete any additional value associated with an element.
   *
   * Currently only applicable to file uploads.
   *
   * @param array $element
   *   An element.
   * @param \Drupal\yamlform\YamlFormSubmissionInterface $yamlform_submission
   *   A YAML form submission.
   */
  public function postDelete(array &$element, YamlFormSubmissionInterface $yamlform_submission);

  /**
   * Format an element's value as HTML.
   *
   * @param array $element
   *   An element.
   * @param array|mixed $value
   *   A value.
   *
   * @return string
   *   The element's value formatted as HTML.
   */
  public function formatHtml(array &$element, $value);

  /**
   * Format an element's value as plain text.
   *
   * @param array $element
   *   An element.
   * @param array|mixed $value
   *   A value.
   *
   * @return string
   *   The element's value formatted as plain text.
   */
  public function formatText(array &$element, $value);

}
