<?php

/**
 * @file
 * Contains Drupal\yamlform\YamlFormEntityForm.
 */

namespace Drupal\yamlform;

use Drupal\Core\Entity\BundleEntityFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Base for controller for YAML form.
 */
class YamlFormEntityForm extends BundleEntityFormBase {

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    if ($this->operation == 'duplicate') {
      $form['#title'] = $this->t('<em>Duplicate YAML form</em> @label', ['@label' => $this->entity->label()]);
      $this->entity = $this->entity->createDuplicate();
    }

    /** @var \Drupal\yamlform\YamlFormInterface $yamlform */
    $yamlform = $this->entity;

    $form['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#maxlength' => 255,
      '#default_value' => $yamlform->label(),
      '#required' => TRUE,
    ];
    $form['id'] = [
      '#type' => 'machine_name',
      '#default_value' => $yamlform->id(),
      '#machine_name' => [
        'exists' => '\Drupal\yamlform\Entity\YamlForm::load',
        'source' => ['title'],
      ],
      '#disabled' => (bool) $yamlform->id() && $this->operation != 'duplicate',
      '#required' => TRUE,
    ];
    $form['description'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Administrative description'),
      '#default_value' => $yamlform->get('description'),
    ];

    $form['inputs'] = [
      '#title' => $this->t('Inputs (YAML)'),
      '#type' => 'yamlform_codemirror',
      '#default_value' => $yamlform->get('inputs'),
      '#required' => TRUE,
    ];

    $form = parent::form($form, $form_state);
    return $this->protectBundleIdElement($form);
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    /** @var \Drupal\yamlform\YamlFormInterface $yamlform */
    $yamlform = $this->getEntity();
    $yamlform->save();

    $this->logger('yamlform')->notice('YAML form @label inputs saved.', ['@label' => $yamlform->label()]);
    drupal_set_message($this->t('YAML form %label inputs saved.', ['%label' => $yamlform->label()]));

    $form_state->setRedirectUrl($yamlform->toUrl());
  }

}
