<?php

/**
 * @file
 * Contains \Drupal\yamlform\YamlFormSubmissionInterface.
 */

namespace Drupal\yamlform;

use Drupal\user\EntityOwnerInterface;
use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Provides an interface defining a YAML form submission entity.
 */
interface YamlFormSubmissionInterface extends ContentEntityInterface, EntityOwnerInterface {

  /**
   * Gets the YAML form submission's data.
   *
   * @param string $key
   *   A string that maps to a key in the submission's data.
   *   If no key is specified, then the entire data array is returned.
   *
   * @return array
   *   The YAML form submission data.
   */
  public function getData($key = NULL);

  /**
   * Set the YAML form submission's data.
   *
   * @param array $data
   *   The YAML form submission data.
   */
  public function setData(array $data);

  /**
   * Gets the YAML form submission's original data before any changes..
   *
   * @param string $key
   *   A string that maps to a key in the submission's original data.
   *   If no key is specified, then the entire data array is returned.
   *
   * @return array
   *   The YAML form submission original data.
   */
  public function getOriginalData($key = NULL);

  /**
   * Gets the YAML form submission's token.
   *
   * @return array
   *   The YAML form submission data.
   */
  public function getToken();

  /**
   * Gets the YAML form submission's YAML form entity.
   *
   * @return \Drupal\yamlform\Entity\YamlForm
   *   The YAML form entity.
   */
  public function getYamlForm();

  /**
   * Gets the YAML form submission's source entity.
   *
   * @return \Drupal\Core\Entity\EntityInterface|null
   *   The entity that this YAML form submission was created from.
   */
  public function getSourceEntity();

  /**
   * Gets the YAML form submission's source URL.
   *
   * @return \Drupal\Core\Url|false
   *   The source URL.
   */
  public function getSourceUrl();

  /**
   * Invoke all YAML form handlers method.
   *
   * @param string $method
   *   The YAML form handler method to be invoked.
   */
  public function invokeYamlFormHandlers($method);

  /**
   * Invoke a YAML form element's method.
   *
   * @param string $method
   *   The YAML form handler method to be invoked.
   * @param array $element
   *   A form element.
   */
  public function invokeYamlFormElement($method, array $element);

}
