<?php

/**
 * @file
 * Contains \Drupal\Tests\yamlform\Unit\YamlFormOptionsHelperTest.
 */

namespace Drupal\Tests\yamlform\Unit;

use Drupal\yamlform\Utility\YamlFormOptionsHelper;
use Drupal\Tests\UnitTestCase;

/**
 * Tests YAML form options utility.
 *
 * @group YamlFormUnit
 *
 * @coversDefaultClass \Drupal\yamlform\Utility\YamlFormOptionsHelper
 */
class YamlFormOptionsHelperTest extends UnitTestCase {

  /**
   * Tests YamlFormOptionsHelper::flattenOptions().
   *
   * @param array $options
   *   The array to run through YamlFormOptionsHelperl::flattenOptions().
   * @param string $expected
   *   The expected result from calling the function.
   *
   * @see YamlFormOptionsHelperl::flattenOptions()
   *
   * @dataProvider providerFlattenOptions
   */
  public function testFlattenOptions(array $options, $expected) {
    $result = YamlFormOptionsHelper::flattenOptions($options);
    $this->assertEquals($expected, $result);
  }

  /**
   * Data provider for testFlattenOptions().
   *
   * @see testFlattenOptions()
   */
  public function providerFlattenOptions() {
    $tests[] = [['value' => 'text'], ['value' => 'text']];
    $tests[] = ['optgroup' => ['value' => 'text'], ['value' => 'text']];
    return $tests;
  }

  /**
   * Tests YamlFormOptionsHelper::getOptionsText().
   *
   * @param array $values
   *   The array to run through YamlFormOptionsHelper::getOptionsText().
   * @param array $options
   *   The array to run through YamlFormOptionsHelper::getOptionsText().
   * @param string $expected
   *   The expected result from calling the function.
   *
   * @see YamlFormOptionsHelperl::getOptionsText()
   *
   * @dataProvider providerGetOptionsText
   */
  public function testGetOptionsText(array $values, array $options, $expected) {
    $result = YamlFormOptionsHelper::getOptionsText($values, $options);
    $this->assertEquals($expected, $result);
  }

  /**
   * Data provider for testGetOptionsText().
   *
   * @see testGetOptionsText()
   */
  public function providerGetOptionsText() {
    $tests[] = [
      ['value'],
      ['value' => 'text'],
      ['text'],
    ];
    $tests[] = [
      [1, 3],
      [1 => 'One', 2 => 'Two', 'optgroup' => [3 => 'Three']],
      ['One', 'Three'],
    ];
    return $tests;
  }

}
