
Contents of this file
---------------------

 * About this module
 * Demo
 * Goals
 * Concepts
 * Example
 * Features
 * Security
 * Installation 
 * Extending
 * Notes
 * References/Related Projects


About this Module
-----------------

The YAML form module enables the creation of forms and questionnaires.

This module should be considered one of the following... 

1. **A lightweight, fast, developer centric, FAPI based form builder and submission 
   manager for Drupal 8.** 
   
2. A temporary solution while other form builders are ported to Drupal 8. 

3. A proof of concept/prototype for a Drupal 8 form builder.

The primary use case for this module is...

- Admin duplicates and customizes an existing form/template.
- Admin tests and publishes the new form.
- User fills in and submits the form.
- Submission is stored in the database.
- Admin receives an email notification. 
- User receives an email confirmation.
- Admin views submissions online.
- Admin downloads all submissions as a CVS.

Don't use this module if you...

- Want [Views](https://www.drupal.org/node/1912118) integration.
- Prefer drag-n-drop form builders.
- Have 'untrusted' users building forms. 

Use this module if you...

- Understand [Render Arrays](https://www.drupal.org/developing/api/8/render/arrays),
  [FAPI](https://www.drupal.org/node/2117411),
  and [YAML](https://en.wikipedia.org/wiki/YAML).
- Prefer
  [CLI](https://en.wikipedia.org/wiki/Command-line_interface)
  over [GUI](https://en.wikipedia.org/wiki/Graphical_user_interface).
- Have 'trusted' developers building and customizing forms. 

Additional things to consider...

- Results can be exported as a CVS for use in 
  [Google Sheets](https://www.google.com/sheets/about/)
  or [Excel](https://products.office.com/en-us/excel).
- The alternatives: 
  [Contact](https://www.drupal.org/documentation/modules/contact),
  [Eform](https://www.drupal.org/project/eform),
  [Webform](https://www.drupal.org/project/webform),
  [Google Forms](https://www.google.com/forms/about/),
  [Webform.com](https://www.drupal.org/project/webform),
  [Wufoo](http://www.wufoo.com/),
  [etc...](https://www.google.com/search?q=Form+builders)
- How can you help extend and improve this module?


Demo
----

> Evaluate this project online using [simplytest.me](https://simplytest.me/project/yamlform).


Goals
-----

- A stable and tested API for building forms and submission handling. 
- A pluggable/extensible API for custom submission handling. 
- A focused and limited feature set to ensure maintainable. 


Concepts
--------

- What is the simpliest and fastest way to create a form builder and submission
  manager in Drupal 8?
- How much can Drupal 8's Form and Entity API be leveraged to
  build a form builder and submission manager?
- Building and maintaining a form building UI consumes a lot of time 
  and resources.
- YAML as a markup language is simple... so simple it could be presented as the 
  UI for building and maintaining forms in Drupal.
- Replace complexity with extensibility


Example
-------

Here is an example of a contact form written in YAML.

    name:
      '#title': 'Your Name'
      '#type': textfield
      '#required': true
    email:
      '#title': 'Your Email'
      '#type': email
      '#required': true
    subject:
      '#title': 'Subject'
      '#type': textfield
      '#required': true
    message:
      '#title': 'Message'
      '#type': textarea
      '#required': true


Features
--------
    
**Forms** 

- Create forms using Drupal's Form API (FAPI)
- Custom confirmation page, message, and redirection
- Reusable and customizable list of common select menu, radios, and checkbox 
  options. This includes countries, states, etc...
- Starter templates for common forms
- Ability to duplicate existing forms and templates
- Prepopulate form with customizable test data.

**Inputs**

- Support for every
  [form element](https://api.drupal.org/api/drupal/developer!topics!forms_api_reference.html/8)
  included in Drupal 8 core.
- File uploads
- Entity references
- Conditional logic using FAPI States API
- Private inputs/elements

**Submissions/Results**

- View submissions as HTML, plain text, and YAML
- Export results as a CSV to Google Sheets or MS Excel
- Drush support

**Emails/Handlers**

- Extensible form submission handler plugin  
- Handles email notifications and confirmations 

**Integration**

- Block integration
- Node integration
- Token support
- YAML editor via [CodeMirror](https://codemirror.net/)

**Still Under Development**

- Unit and Simple Tests
- Advanced export functionality
- Permissions and access controls
- Advanced Views integration
  
Security
--------

This module allows developers to have full access to Drupal's Render API,
this includes the ability to set [callbacks](http://php.net/manual/en/language.types.callable.php),
which are PHP functions that are executed during the rendering process.
This means anyone who can administer and build a YAML form can call any PHP code
on your website.

> Only the most trusted users should be granted permission to administer and
  build YAML forms.

_Please note: Administering and exporting a YAML form's results is a dedicated
and secure role._
 
Installation
------------

1. Copy/upload the yamlform.module to the modules directory of your Drupal
   installation.
2. (optional) Install CodeMirror 5.10+ in /libraries/codemirror directory.
   If CodeMiror is not installed, it will be loaded from
   <https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.10.0/>.
3. Enable the 'YAML form' module in 'Extend'. (/admin/modules)
4. Setup permissions. (/admin/people/permissions#module-yamlform)
5. Begin building a new YAML form or duplicate an existing one.
  (/admin/structure/yamlform)
6. Publish your new YAML form as a...
    - **Page:** By linking to the published YAML form.
      (/yamlform/contact)  
    - **Node:** By creating a new node that references the YAML form.
      (/node/add/yamlform)
    - **Block:** By placing a YAML form block on your site.
      (/admin/structure/block)


Extending
---------

YAML form will use [Drupal 8's plugin API](https://www.drupal.org/developing/api/8/plugins)
to manage all customizations.  

Each YamlFormHandler plugin should live in a dedicated module and handler
namespace.  For example, if a developer wanted to setup MailChimp integration,
they would create the YAML form MailChimp module (yamlform_mailchimp.module)
which would contain the YamlFormMailChimpHandler.

This approach/pattern will allow any popular YamlFormHandler plugins
(that include tests) to be easily contributed back to the main YAML form module.
     
The goal is to allow YAML forms to be extended without creating any new hooks 
and just use the YamlFormHandler plugin for customizing form building and 
submission handling.    
     

Notes
-----

- Input names will be used to store data.
- Duplicate input names are not allowed.
- The [#tree](https://api.drupal.org/api/drupal/developer!topics!forms_api_reference.html/8#tree) 
  property, which is used to allow collections of form elements, is not allowed.
- Element callback properties are not supported within a YAML input.
  This includes `#element_validate`, `#after_build`, `#post_render`, `#pre_render`, `#process`, `#submit`, `#value_callback`, and `#validate`.
- Once there has been a form submission, existing input names should never be
  deleted, they can be be hidden (via `'#access': false`).
  _A validation handler might need to be setup to enforce this rule._


References/Related Projects
---------------------------

- [YAML](http://www.yaml.org/start.html)
- [Comparison of Form Building Modules](https://www.drupal.org/node/2083353)
- [Contact](https://www.drupal.org/documentation/modules/contact) 
    - [Contact module 8.1 and beyond roadmap](https://www.drupal.org/node/2582955)
    - [Goodbye Webform? Contact Forms Are In the Drupal 8 Core](https://www.ostraining.com/blog/drupal/drupal-8-contact-forms/)
- [Eform](https://www.drupal.org/project/eform)
    - [When to use Entityform](https://www.drupal.org/node/1540680)
- [Webform](https://www.drupal.org/project/webform) 
    - [Port Webform to Drupal 8](https://www.drupal.org/node/2075941)


Author/Maintainer
-----------------

- [Jacob Rockowitz](http://drupal.org/user/371407)
